Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(5152)

Unified Diff: components/password_manager/core/browser/password_manager.h

Issue 380713003: PasswordManager - update "password_manager_enabled_" pref name (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Created 6 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: components/password_manager/core/browser/password_manager.h
diff --git a/components/password_manager/core/browser/password_manager.h b/components/password_manager/core/browser/password_manager.h
index 45a7f93fa47ac6c34420636852c080608e5f69fc..9ffb6b6fee13e66645859d35e11ef0c3d8244132 100644
--- a/components/password_manager/core/browser/password_manager.h
+++ b/components/password_manager/core/browser/password_manager.h
@@ -178,9 +178,9 @@ class PasswordManager : public LoginModel {
// The platform-level driver. Must outlive this class.
PasswordManagerDriver* const driver_;
// Set to false to disable the password manager (will no longer ask if you
// want to save passwords but will continue to fill passwords).
- BooleanPrefMember password_manager_enabled_;
+ BooleanPrefMember saving_password_enabled_;
vabr (Chromium) 2014/07/10 08:36:54 nit: saving_passwords_enabled_ (plural, as this ap
Nikhil 2014/07/10 09:56:35 Done.
// Observers to be notified of LoginModel events. This is mutable to allow
@@ -178,9 +178,9 @@ class PasswordManager : public LoginModel {
// The platform-level driver. Must outlive this class.
PasswordManagerDriver* const driver_;
- // Set to false to disable the password manager (will no longer ask if you
+ // Set to false to disable password saving (will no longer ask if you
// want to save passwords but will continue to fill passwords).
// notification in const member functions.

Powered by Google App Engine
This is Rietveld 408576698